﻿using System.Collections;
using System;
using UnityEngine;

namespace Mod
{
    public class Mod : MonoBehaviour
    {
        public static void Main()
        {ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
        NameOverride = "Skeleton -SkeletonMod", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "Spooky scary skeleton.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("sklton.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //load textures for each layer (see Human textures folder in this repository)
            var skin = ModAPI.LoadTexture("skeleton1.png");
            var flesh = ModAPI.LoadTexture("skeleton1.png");
            var bone = ModAPI.LoadTexture("skeleton1.png");

            //get person
            var person = Instance.GetComponent<PersonBehaviour>();

            //use the helper function to set each texture
            //parameters are as follows: 
            //  skin texture, flesh texture, bone texture, sprite scale
            //you can pass "null" to fall back to the original texture
            person.SetBodyTextures(skin, flesh, bone, 1);

            //change procedural damage colours if they interfere with your texture (rgb 0-255)
            person.SetBruiseColor(88, 88, 88); //main bruise colour. purple-ish by default
            person.SetSecondBruiseColor(66, 33, 22); //second bruise colour. red by default
            person.SetThirdBruiseColor(44, 22, 20); // third bruise colour. light yellow by default
            person.SetRottenColour(95, 130, 12); // rotten/zombie colour. light yellow/green by default
            person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
        }
    }
);
        // register item to the mod api
        ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Knife"), //item to derive from
        NameOverride = "Sharp bone -SkeletonMod", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "It can pierce through skin! ...and bones.", //new item description
        CategoryOverride = ModAPI.FindCategory("Melee"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("bone.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //get the SpriteRenderer and replace its sprite with a custom one
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("bone.png");
            Instance.FixColliders();
        }
    }
);
        // register item to the mod api
        ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Stick"), //item to derive from
        NameOverride = "Bone -SkeletonMod", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "bonk.", //new item description
        CategoryOverride = ModAPI.FindCategory("Melee"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("bone2.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //get the SpriteRenderer and replace its sprite with a custom one
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("bone2.png");
            Instance.FixColliders();
        }
    }
);
    ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Pistol"), //item to derive from
        NameOverride = "BoneGun -SkeletonMod", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "It dosen't shoot with bones. It's just make with bones, and it's really weak.", //new item description
        CategoryOverride = ModAPI.FindCategory("Firearms"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("bonegun.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //setting the sprite
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("bonegun.png");

            //getting the FirearmBehaviour for later manipulation
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //creating a custom cartridge for the gun
            Cartridge customCartridge = ModAPI.FindCartridge("9mm"); //load a copy of the 9mm cartridge
            customCartridge.name = "BoneCatridge"; //set a name
            customCartridge.Damage *= 0.25f; //change the damage however you like
            customCartridge.StartSpeed *= 0.25f; //change the bullet velocity
            customCartridge.PenetrationRandomAngleMultiplier *= 0.75f; //change the accuracy when the bullet travels through an object
            customCartridge.Recoil *= 0.75f; //change the recoil
            customCartridge.ImpactForce *= 1.0f; //change how much the bullet pushes the target

            //set the cartridge to the FirearmBehaviour
            firearm.Cartridge = customCartridge;

            //set the new gun sounds. this is an array of AudioClips that is picked from at random when shot
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("boneshoot.wav")
            };

            Instance.FixColliders();
        }
    }
);
        }
    }
}